@@ -44,15 +44,17 @@ class SASdata:
         - obs is a numbers - either string or int
         - first obs is a numbers - either string or int
         - format is a string or dictionary { var: format }
+        - encoding is a string
 
         .. code-block:: python
 
-                         {'where'    : 'msrp < 20000 and make = "Ford"',
-                          'keep'     : 'msrp enginesize Cylinders Horsepower Weight',
-                          'drop'     : ['msrp', 'enginesize', 'Cylinders', 'Horsepower', 'Weight'],
-                          'obs'      :  10,
-                          'firstobs' : '12'
-                          'format'  : {'money': 'dollar10', 'time': 'tod5.'}
+                         {'where'    : 'msrp < 20000 and make = "Ford"' ,
+                          'keep'     : 'msrp enginesize Cylinders Horsepower Weight' ,
+                          'drop'     : ['msrp', 'enginesize', 'Cylinders', 'Horsepower', 'Weight'] ,
+                          'obs'      :  10 ,
+                          'firstobs' : '12' ,
+                          'format'   : {'money': 'dollar10', 'time': 'tod5.'} ,
+                          'encoding' : 'latin9'
                          }
 
     """
@@ -1080,8 +1082,8 @@ class SASdata:
 
            - MEMORY the original method. Streams the data over and builds the dataframe on the fly in memory
            - CSV    uses an intermediary Proc Export csv file and pandas read_csv() to import it; faster for large data
-           - DISK   uses the original (MEMORY) method, but persists to disk and uses pandas read to import.
-                    this has better support than CSV for embedded delimiters (commas), nulls, CR/LF that CSV
+           - DISK   uses the original (MEMORY) method, but persists to disk and uses pandas read to import.   \
+                    this has better support than CSV for embedded delimiters (commas), nulls, CR/LF that CSV  \
                     has problems with 
 
 
