@@ -126,7 +126,7 @@ class SASconfigHTTP:
 
       inver = kwargs.get('verify', None)         
       if inver is not None:
-         if lock and self.ssl:
+         if lock and self.verify:
             print("Parameter 'verify' passed to SAS_session was ignored due to configuration restriction.")
          else:
             self.verify = bool(inver)
@@ -246,7 +246,7 @@ class SASconfigHTTP:
                self.HTTPConn = hc.HTTPSConnection(self.ip, self.port, timeout=self.timeout)
                self._token = self._authenticate(user, pw)
             except ssl.SSLError as e:
-               print("SSL connection failed, creating an unverified ssl connection. Error was:"+str(e))
+               print("SSL certificate verification failed, creating an unverified SSL connection. Error was:"+str(e))
                self.HTTPConn = hc.HTTPSConnection(self.ip, self.port, timeout=self.timeout, context=ssl._create_unverified_context())
                print("You can set 'verify=False' to get rid of this message ")
                self._token   = self._authenticate(user, pw)
@@ -376,7 +376,7 @@ class SASconfigHTTP:
       headers={"Accept":"application/vnd.sas.collection+json",
                "Accept-Item":"application/vnd.sas.compute.context.summary+json",
                "Authorization":"Bearer "+self._token}
-      conn.request('GET', "/compute/contexts", headers=headers)
+      conn.request('GET', "/compute/contexts?limit=999999", headers=headers)
       req = conn.getresponse()
       status = req.status
       resp = req.read()
@@ -1130,7 +1130,8 @@ class SASsessionHTTP():
                                           embedded_newlines: bool=True,
                          LF: str = '\x01', CR: str = '\x02',
                          colsep: str = '\x03', colrep: str = ' ',
-                         datetimes: dict={}, outfmts: dict={}, labels: dict={}):
+                         datetimes: dict={}, outfmts: dict={}, labels: dict={},
+                         outencoding: str = ''):
       '''
       This method imports a Pandas Data Frame to a SAS Data Set, returning the SASdata object for the new Data Set.
       df      - Pandas Data Frame to import to a SAS Data Set
@@ -1225,7 +1226,11 @@ class SASsessionHTTP():
       code = "data "
       if len(libref):
          code += libref+"."
-      code += "'"+table.strip()+"'n;\n"
+      code += "'"+table.strip()+"'n"
+      if len(outencoding):
+         code += '(encoding="'+outencoding+'");\n'
+      else:
+         code += ";\n"
       if len(length):
          code += "length "+length+";\n"
       if len(format):
@@ -1377,7 +1382,7 @@ class SASsessionHTTP():
       uri = "/compute/sessions/"+self.pid+"/data/work/saspy_ds2df/rows"
 
       r     = []
-      df    = pd.DataFrame.from_records(r, columns=varlist)
+      df    = None
       trows = kwargs.get('trows', None)
       if not trows:
          trows = 100000
@@ -1435,7 +1440,8 @@ class SASsessionHTTP():
          for i in range(nvars):
             if vartype[i] == 'FLOAT':
                if varcat[i] not in self._sb.sas_date_fmts + self._sb.sas_time_fmts + self._sb.sas_datetime_fmts:
-                  tdf[varlist[i]] = pd.to_numeric(tdf[varlist[i]], errors='coerce') 
+                  if tdf.dtypes[tdf.columns[i]].kind not in ('f','u','i','b','B','c','?'):
+                     tdf[varlist[i]] = pd.to_numeric(tdf[varlist[i]], errors='coerce') 
                else:
                   tdf[varlist[i]] = pd.to_datetime(tdf[varlist[i]], errors='coerce') 
             else:
